@@ -6,10 +6,10 @@ from click.core import Context
 
 from chenv import fs, settings, transform
 from chenv.console import as_link, Color, fatal
-from chenv.models.output import Output, Target
+from chenv.models.output import Output
 from . import __version__
 
-settings.load()
+settings.mount()
 
 
 @click.group(invoke_without_command=True)
@@ -25,16 +25,13 @@ def cli(ctx: Context) -> None:
 
 
 @cli.resultcallback()
-def _pipeline(result: Optional[Target]) -> None:
+def _pipeline(result: Optional[Output]) -> None:
     try:
         if result is None or result.file_suffix is None:
             return
 
-        if isinstance(result, Output):
-            transformed_output: Output = transform.apply(result)
-            fs.assign_env(transformed_output)
-        else:
-            fs.force_link(result.filename)
+        transformed_output: Output = transform.apply(result)
+        fs.assign_env(transformed_output.filename, transformed_output.variables)
         click.echo(as_link(result.filename, Color.BRIGHT_GREEN))
     except Exception as e:
         fatal(__name__, f"{e.__class__.__name__} - {str(e)}", 1)
